2009/dap/docs/lrest gallery-lrest.html,1.3,1.4 gallery-lrest.js,1.3,1.4

Update of /sources/public/2009/dap/docs/lrest
In directory hutz:/tmp/cvs-serv15835

Modified Files:
	gallery-lrest.html gallery-lrest.js 
Log Message:
small edit 2

Index: gallery-lrest.html
===================================================================
RCS file: /sources/public/2009/dap/docs/lrest/gallery-lrest.html,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- gallery-lrest.html	11 Feb 2010 16:17:35 -0000	1.3
+++ gallery-lrest.html	11 Feb 2010 16:19:13 -0000	1.4
@@ -29,7 +29,7 @@
     <div id='big' style='text-align: center'><img/></div>
     <hr/>
     <pre id='log'></pre>
-    <div id='infauxbox' style='display: none; position: fixed; top: 0; left: 0; width: 100%; background: #000; color: #fff; font-size: 0.8em;'>
+    <div id='infauxbar' style='display: none; position: fixed; top: 0; left: 0; width: 100%; background: #000; color: #fff; font-size: 0.8em;'>
       <p style='float: left; padding: 0; margin: 10px 0 10px 10px'>
         This application wants to access your super-personal gallery: <span id='access' style='font-weight: bold;'></span>.
         <span style='font-style: italic; text-decoration: underline'>Dude, I'm lost. WTF?</span>

Index: gallery-lrest.js
===================================================================
RCS file: /sources/public/2009/dap/docs/lrest/gallery-lrest.js,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- gallery-lrest.js	11 Feb 2010 16:17:35 -0000	1.3
+++ gallery-lrest.js	11 Feb 2010 16:19:13 -0000	1.4
@@ -23,8 +23,8 @@
         ],
     };
 
-    // silly InfauxBox
-    var InfauxBox = {
+    // silly InfauxBar
+    var InfauxBar = {
         rememberYes: {},
         rememberNo: {},
         auth:   function (uri, cb, ctx, prm) {
@@ -35,8 +35,8 @@
             for (var i = 0; i < navigator.services.galleries.length; i++) {
                 if (navigator.services.galleries[i].uri == uri) name = navigator.services.galleries[i].name;
             }
-            // show the infauxbox
-            var $ifb = $("#infauxbox");
+            // show the infauxbar
+            var $ifb = $("#infauxbar");
             var r = $("#remember")[0];
             $("#access").text(name);
             var obj = this;
@@ -88,7 +88,7 @@
         send:   function (data) {
             // log("send called with", data, this.isMagic);
             if (!this.isMagic) return this.xhr.send.apply(this.xhr, arguments);
-            InfauxBox.auth(this.uri, function (data) {
+            InfauxBar.auth(this.uri, function (data) {
                 var obj = this;
                 GLOBAL.jsonFlickrFeed = function (o) {
                     if (!obj.cb) return;

Received on Thursday, 11 February 2010 16:19:18 UTC